--[[
AdiBags - Dragonflight
by Zottelchen
version: 1.1.4
Add various Dragonflight items to AdiBags filter groups
]]

local addonName, addon = ...
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")

local L = addon.L
local MatchIDs
local Result = {}

local function AddToSet(List)
    local Set = {}
    for _, v in ipairs(List) do
        Set[v] = true
    end
    return Set
end

local function unescape(String)
    local unescaped = tostring(String)
    unescaped = gsub(unescaped, "|c........", "") -- Remove color start.
    unescaped = gsub(unescaped, "|r", "") -- Remove color end.
    -- Result = gsub(Result, "|H.-|h(.-)|h", "%1") -- Remove links.
    -- Result = gsub(Result, "|T.-|t", "") -- Remove textures.
    -- Result = gsub(Result, "{.-}", "") -- Remove raid target icons.
    return unescaped
end


 -- PreEvent Gear
local PreEventGearIDs = {
199348, -- Cloudburst Robes
199349, -- Cloudburst Slippers
199350, -- Cloudburst Mitts
199351, -- Cloudburst Hood
199352, -- Cloudburst Breeches
199353, -- Cloudburst Mantle
199354, -- Cloudburst Sash
199355, -- Cloudburst Bindings
199356, -- Dust Devil Raiment
199357, -- Dust Devil Treads
199358, -- Dust Devil Gloves
199359, -- Dust Devil Mask
199360, -- Dust Devil Leggings
199361, -- Dust Devil Epaulets
199362, -- Dust Devil Cincture
199363, -- Dust Devil Wristbands
199364, -- Cyclonic Chainmail
199365, -- Cyclonic Striders
199366, -- Cyclonic Gauntlets
199367, -- Cyclonic Cowl
199368, -- Cyclonic Kilt
199369, -- Cyclonic Spaulders
199370, -- Cyclonic Cinch
199371, -- Cyclonic Bracers
199372, -- Firestorm Chestplate
199373, -- Firestorm Stompers
199374, -- Firestorm Crushers
199375, -- Firestorm Greathelm
199376, -- Firestorm Greaves
199377, -- Firestorm Pauldrons
199378, -- Firestorm Girdle
199379, -- Firestorm Vambraces
199380, -- Cyclonic Drape
199381, -- Seal of Elemental Disasters
199382, -- Catastrophe Signet
199383, -- Torc of Calamities
199384, -- Cloudburst Wrap
199385, -- Dust Devil Cloak
199386, -- Firestorm Cape
199399, -- Galerider Poleaxe
199400, -- Squallbreaker Greatsword
199401, -- Stormbender Scroll
199402, -- Galepiercer Ballista
199403, -- Stormbender Maul
199404, -- Squallbreaker Shield
199405, -- Stormbender Rod
199406, -- Galerider Mallet
199407, -- Galerider Shank
199408, -- Squallbreaker Longblade
199409, -- Stormbender Saber
199416, -- Galerider Crescent
199555, -- Versatile Storm Lure
199645, -- Storm Hunter's Insignia
}

 -- Alchemy
local AlchemyIDs = {
191474, -- Draconic Vial
191475, -- Draconic Vial
191476, -- Draconic Vial
}

 -- PreEvent Currency
local PreEventCurrencyIDs = {
199211, -- Primeval Essence
199836, -- Dimmed Primeval Fire
199837, -- Dimmed Primeval Earth
199838, -- Dimmed Primeval Storm
199839, -- Dimmed Primeval Water
}

 -- Leather
local LeatherIDs = {
193208, -- Resilient Leather
193210, -- Resilient Leather
193211, -- Resilient Leather
193213, -- Adamant Scales
193214, -- Adamant Scales
193215, -- Adamant Scales
193216, -- Dense Hide
193217, -- Dense Hide
193218, -- Dense Hide
193222, -- Lustrous Scaled Hide
193223, -- Lustrous Scaled Hide
193224, -- Lustrous Scaled Hide
193226, -- Stonecrust Hide
193227, -- Stonecrust Hide
193228, -- Stonecrust Hide
193229, -- Mireslush Hide
193230, -- Mireslush Hide
193231, -- Mireslush Hide
193232, -- Deathchill Hide
193233, -- Deathchill Hide
193234, -- Deathchill Hide
193236, -- Infurious Hide
193237, -- Infurious Hide
193238, -- Infurious Hide
193239, -- Drygrate Scales
193240, -- Drygrate Scales
193241, -- Drygrate Scales
193242, -- Earthshine Scales
193243, -- Earthshine Scales
193244, -- Earthshine Scales
193245, -- Frostbite Scales
193246, -- Frostbite Scales
193247, -- Frostbite Scales
193248, -- Infurious Scales
193249, -- Infurious Scales
193250, -- Infurious Scales
193251, -- Crystalspine Fur
193252, -- Salamanther Scales
193253, -- Cacophonous Thunderscale
193254, -- Rockfang Leather
193255, -- Pristine Vorquin Horn
193256, -- Windsong Plumage
193258, -- Fire-Infused Hide
193259, -- Flawless Proto Dragon Scale
193261, -- Bite-Sized Morsel
193262, -- Exceptional Morsel
197735, -- Finished Prototype Explorer's Barding
197736, -- Finished Prototype Regal Barding
}

 -- Enchanting
local EnchantingIDs = {
193057, -- 10.0 Placeholder Enchanting Crystal
194123, -- Chromatic Dust
194124, -- Vibrant Shard
200113, -- Resonant Crystal
201584, -- Serevite Rod
}

 -- Engineering
local EngineeringIDs = {
198183, -- Handful of Serevite Bolts
198184, -- Handful of Serevite Bolts
198185, -- Handful of Serevite Bolts
198186, -- Shock-Spring Coil
198187, -- Shock-Spring Coil
198188, -- Shock-Spring Coil
198189, -- Everburning Blasting Powder
198190, -- Everburning Blasting Powder
198191, -- Everburning Blasting Powder
198192, -- Greased-Up Gears
198193, -- Greased-Up Gears
198194, -- Greased-Up Gears
198195, -- Arclight Capacitor
198196, -- Arclight Capacitor
198197, -- Arclight Capacitor
198198, -- Reinforced Machine Chassis
198199, -- Reinforced Machine Chassis
198200, -- Reinforced Machine Chassis
198201, -- Assorted Safety Fuses
198202, -- Assorted Safety Fuses
198203, -- Assorted Safety Fuses
201832, -- Smudged Lens
}

 -- Inscription
local InscriptionIDs = {
194751, -- Blazing Ink
194752, -- Blazing Ink
194754, -- Cosmic Ink
194755, -- Cosmic Ink
194756, -- Cosmic Ink
194758, -- Flourishing Ink
194760, -- Burnished Ink
194761, -- Burnished Ink
194767, -- Chilled Rune
194768, -- Chilled Rune
194784, -- Glittering Parchment
194824, -- Chirping Rune
194825, -- Chirping Rune
194826, -- Chirping Rune
194846, -- Blazing Ink
194850, -- Flourishing Ink
194852, -- Flourishing Ink
194855, -- Burnished Ink
194856, -- Serene Ink
194857, -- Serene Ink
194858, -- Serene Ink
194859, -- Chilled Rune
194862, -- Runed Writhebark
194863, -- Runed Writhebark
194864, -- Runed Writhebark
198412, -- Serene Pigment
198413, -- Serene Pigment
198414, -- Serene Pigment
198415, -- Flourishing Pigment
198416, -- Flourishing Pigment
198417, -- Flourishing Pigment
198418, -- Blazing Pigment
198419, -- Blazing Pigment
198420, -- Blazing Pigment
198421, -- Shimmering Pigment
198422, -- Shimmering Pigment
198423, -- Shimmering Pigment
}

 -- General Crafting
local GeneralCraftingIDs = {
194785, -- Ace of Fire
194786, -- Two of Fire
194787, -- Three of Fire
194788, -- Four of Fire
194789, -- Five of Fire
194790, -- Six of Fire
194791, -- Seven of Frost
194792, -- Eight of Fire
194793, -- Ace of Frost
194794, -- Two of Frost
194795, -- Three of Frost
194796, -- Four of Frost
194797, -- Five of Frost
194798, -- Six of Frost
194799, -- Seven of Fire
194800, -- Eight of Frost
194801, -- Ace of Air
194802, -- Two of Air
194803, -- Three of Air
194804, -- Four of Air
194805, -- Five of Air
194806, -- Six of Air
194807, -- Seven of Air
194808, -- Eight of Air
194809, -- Ace of Earth
194810, -- Two of Earth
194811, -- Three of Earth
194812, -- Four of Earth
194813, -- Five of Earth
194814, -- Six of Earth
194815, -- Seven of Earth
194816, -- Eight of Earth
194827, -- Bundle O' Cards: Dragon Isles
198614, -- Soggy Clump of Darkmoon Cards
}

 -- Treasure Sacks
local TreasureSacksIDs = {
199341, -- Regurgitated Sac of Swog Treasures
199342, -- Weighted Sac of Swog Treasures
199343, -- ERROR
202102, -- Immaculate Sac of Swog Treasures
202103, -- ERROR
202104, -- ERROR
}

 -- Herbs
local HerbsIDs = {
191460, -- Hochenblume
191461, -- Hochenblume
191462, -- Hochenblume
191464, -- Saxifrage
191465, -- Saxifrage
191466, -- Saxifrage
191467, -- Bubble Poppy
191468, -- Bubble Poppy
191469, -- Bubble Poppy
191470, -- Writhebark
191471, -- Writhebark
191472, -- Writhebark
}

 -- Mining
local MiningIDs = {
188658, -- Draconium Ore
189143, -- Draconium Ore
189541, -- Primal Molten Alloy
189542, -- Primal Molten Alloy
189543, -- Primal Molten Alloy
190311, -- Draconium Ore
190312, -- Khaz'gorite Ore
190313, -- Khaz'gorite Ore
190314, -- Khaz'gorite Ore
190394, -- Serevite Ore
190395, -- Serevite Ore
190396, -- Serevite Ore
190452, -- Primal Flux
190530, -- Frostfire Alloy
190531, -- Frostfire Alloy
190532, -- Frostfire Alloy
190533, -- Obsidian Seared Alloy
190534, -- Obsidian Seared Alloy
190535, -- Obsidian Seared Alloy
190536, -- Infurious Alloy
190537, -- Infurious Alloy
190538, -- Infurious Alloy
194545, -- Prismatic Ore
}

 -- Cloth
local ClothIDs = {
192095, -- Spool of Wilderthread
192096, -- Spool of Wilderthread
192097, -- Spool of Wilderthread
193050, -- Tattered Wildercloth
193053, -- Contoured Fowlfeather
193922, -- Wildercloth
193923, -- Decayed Wildercloth
193924, -- Frostbitten Wildercloth
193925, -- Singed Wildercloth
193926, -- Wildercloth Bolt
193927, -- Wildercloth Bolt
193928, -- Wildercloth Bolt
193929, -- Vibrant Wildercloth Bolt
193930, -- Vibrant Wildercloth Bolt
193931, -- Vibrant Wildercloth Bolt
193932, -- Infurious Wildercloth Bolt
193933, -- Infurious Wildercloth Bolt
193934, -- Infurious Wildercloth Bolt
193935, -- Chronocloth Bolt
193936, -- Chronocloth Bolt
193937, -- Chronocloth Bolt
193938, -- Azureweave Bolt
193939, -- Azureweave Bolt
193940, -- Azureweave Bolt
}

 -- Cooking
local CookingIDs = {
194730, -- Scalebelly Mackerel
194966, -- Thousandbite Piranha
194967, -- Aileron Seamoth
194968, -- Cerulean Spinefish
194969, -- Temporal Dragonhead
194970, -- Islefin Dorado
197741, -- Maybe Meat
197742, -- Ribbed Mollusk Meat
197743, -- Waterfowl Filet
197744, -- Hornswog Hunk
197745, -- Basilisk Eggs
197746, -- Bruffalon Flank
197747, -- Mighty Mammoth Ribs
197748, -- Burly Bear Haunch
197749, -- Ohn'ahran Potato
197750, -- Three-Cheese Blend
197751, -- Pastry Packets
197752, -- Conveniently Packaged Ingredients
197753, -- Thaldraszian Cocoa Powder
197754, -- Salt Deposit
197755, -- Lava Beetle
197756, -- Pebbled Rock Salts
197757, -- Assorted Exotic Spices
198395, -- Dull Spined Clam
199063, -- Salted Fish Scraps
199100, -- Peppersmelt
199101, -- Dried Wyldermane Kelp
199102, -- Hunk o' Blubber
199103, -- Nappa's Famous Tea
199104, -- Piping-Hot Orca Milk
199105, -- Ancheevy
199106, -- Tiny Leviathan Bone
199205, -- Manasucker
199207, -- Iceback Sculpin
199208, -- Grungle
199212, -- Clubfish
199213, -- Lakkamuk Blenny
199344, -- Magma Thresher
199345, -- Rimefin Tuna
199346, -- Rotten Rimefin Tuna
199832, -- Smoked Seaviper
199833, -- Dragonhead Eel
199834, -- Pulpy Seagrass
199835, -- Torga's Braid
200061, -- Prismatic Leaper
200074, -- Frosted Rimefin Tuna
}

 -- Jewelcrafting
local JewelcraftingIDs = {
192833, -- Misshapen Filigree
192834, -- Shimmering Clasp
192835, -- Shimmering Clasp
192836, -- Shimmering Clasp
192837, -- Queen's Ruby
192838, -- Queen's Ruby
192839, -- Queen's Ruby
192840, -- Mystic Sapphire
192841, -- Mystic Sapphire
192842, -- Mystic Sapphire
192843, -- Vibrant Emerald
192844, -- Vibrant Emerald
192845, -- Vibrant Emerald
192846, -- Sundered Onyx
192847, -- Sundered Onyx
192848, -- Sundered Onyx
192849, -- Eternity Amber
192850, -- Eternity Amber
192851, -- Eternity Amber
192852, -- Alexstraszite
192853, -- Alexstraszite
192855, -- Alexstraszite
192856, -- Malygite
192857, -- Malygite
192858, -- Malygite
192859, -- Ysemerald
192860, -- Ysemerald
192861, -- Ysemerald
192862, -- Neltharite
192863, -- Neltharite
192865, -- Neltharite
192866, -- Nozdorite
192867, -- Nozdorite
192868, -- Nozdorite
192869, -- Illimited Diamond
192870, -- Illimited Diamond
192871, -- Illimited Diamond
192872, -- Fractured Glass
192876, -- Frameless Lens
192877, -- Frameless Lens
192878, -- Frameless Lens
192880, -- Crumbled Stone
192883, -- Glossy Stone
192884, -- Glossy Stone
192885, -- Glossy Stone
192888, -- Queen's Gift
192889, -- Dreamer's Vision
192890, -- Keeper's Glory
192891, -- Earthwarden's Prize
192892, -- Timewatcher's Patience
192893, -- Jeweled Dragon's Heart
192894, -- Blotting Sand
192895, -- Blotting Sand
192896, -- Blotting Sand
192897, -- Pounce
192898, -- Pounce
192899, -- Pounce
193029, -- Projection Prism
193030, -- Projection Prism
193031, -- Projection Prism
193368, -- Silken Gemdust
193369, -- Silken Gemdust
193370, -- Silken Gemdust
198397, -- Rainbow Pearl
200156, -- Amethyzarite Geode
202048, -- Queen's Gift
202049, -- Dreamer's Vision
202050, -- Keeper's Glory
202051, -- Earthwarden's Prize
202052, -- Timewatcher's Patience
202053, -- ERROR
202054, -- Queen's Gift
202055, -- Dreamer's Vision
202056, -- Keeper's Glory
202057, -- Earthwarden's Prize
202058, -- Timewatcher's Patience
202059, -- ERROR
}

 -- Fortune Cards
local FortuneCardsIDs = {
194829, -- Fated Fortune Card
199114, -- Fated Fortune Card
199116, -- Fated Fortune Card
199117, -- Fated Fortune Card
199118, -- Fated Fortune Card
199119, -- Fated Fortune Card
199120, -- Fated Fortune Card
199121, -- Fated Fortune Card
199123, -- Fated Fortune Card
199124, -- Fated Fortune Card
199125, -- Fated Fortune Card
199126, -- Fated Fortune Card
199127, -- Fated Fortune Card
199129, -- Fated Fortune Card
199130, -- Fated Fortune Card
199131, -- Fated Fortune Card
199132, -- Fated Fortune Card
199133, -- Fated Fortune Card
199134, -- Fated Fortune Card
199135, -- Fated Fortune Card
199136, -- Fated Fortune Card
199137, -- Fated Fortune Card
199138, -- Fated Fortune Card
199139, -- Fated Fortune Card
199140, -- Fated Fortune Card
199141, -- Fated Fortune Card
199142, -- Fated Fortune Card
199143, -- Fated Fortune Card
199144, -- Fated Fortune Card
199145, -- Fated Fortune Card
199146, -- Fated Fortune Card
199147, -- Fated Fortune Card
199148, -- Fated Fortune Card
199149, -- Fated Fortune Card
199150, -- Fated Fortune Card
199151, -- Fated Fortune Card
199152, -- Fated Fortune Card
199153, -- Fated Fortune Card
199154, -- Fated Fortune Card
199155, -- Fated Fortune Card
199156, -- Fated Fortune Card
199157, -- Fated Fortune Card
199158, -- Fated Fortune Card
199159, -- Fated Fortune Card
199160, -- Fated Fortune Card
199161, -- Fated Fortune Card
199162, -- Fated Fortune Card
199163, -- Fated Fortune Card
199164, -- Fated Fortune Card
199165, -- Fated Fortune Card
199166, -- Fated Fortune Card
199167, -- Fated Fortune Card
199168, -- Fated Fortune Card
199169, -- Fated Fortune Card
199170, -- Fated Fortune Card
}

 -- Darkmoon Cards
local DarkmoonCardsIDs = {
194785, -- Ace of Fire
194786, -- Two of Fire
194787, -- Three of Fire
194788, -- Four of Fire
194789, -- Five of Fire
194790, -- Six of Fire
194791, -- Seven of Frost
194792, -- Eight of Fire
194793, -- Ace of Frost
194794, -- Two of Frost
194795, -- Three of Frost
194796, -- Four of Frost
194797, -- Five of Frost
194798, -- Six of Frost
194799, -- Seven of Fire
194800, -- Eight of Frost
194801, -- Ace of Air
194802, -- Two of Air
194803, -- Three of Air
194804, -- Four of Air
194805, -- Five of Air
194806, -- Six of Air
194807, -- Seven of Air
194808, -- Eight of Air
194809, -- Ace of Earth
194810, -- Two of Earth
194811, -- Three of Earth
194812, -- Four of Earth
194813, -- Five of Earth
194814, -- Six of Earth
194815, -- Seven of Earth
194816, -- Eight of Earth
194827, -- Bundle O' Cards: Dragon Isles
198614, -- Soggy Clump of Darkmoon Cards
}



local function MatchIDs_Init(self)
    wipe(Result)

    if self.db.profile.movePreEventGear then
        if self.db.profile.showcoloredCategories then
            Result["|cff0050a2PreEvent Gear|r"] = AddToSet(PreEventGearIDs)
        else
            Result[unescape("|cff0050a2PreEvent Gear|r")] = AddToSet(PreEventGearIDs)
        end
    end

    if self.db.profile.moveAlchemy then
        if self.db.profile.showcoloredCategories then
            Result["|cff91ffe9Alchemy|r"] = AddToSet(AlchemyIDs)
        else
            Result[unescape("|cff91ffe9Alchemy|r")] = AddToSet(AlchemyIDs)
        end
    end

    if self.db.profile.movePreEventCurrency then
        if self.db.profile.showcoloredCategories then
            Result["|cff0060a2PreEvent Currency|r"] = AddToSet(PreEventCurrencyIDs)
        else
            Result[unescape("|cff0060a2PreEvent Currency|r")] = AddToSet(PreEventCurrencyIDs)
        end
    end

    if self.db.profile.moveLeather then
        if self.db.profile.showcoloredCategories then
            Result["|cff865b00Leather|r"] = AddToSet(LeatherIDs)
        else
            Result[unescape("|cff865b00Leather|r")] = AddToSet(LeatherIDs)
        end
    end

    if self.db.profile.moveEnchanting then
        if self.db.profile.showcoloredCategories then
            Result["|cff96ff00Enchanting|r"] = AddToSet(EnchantingIDs)
        else
            Result[unescape("|cff96ff00Enchanting|r")] = AddToSet(EnchantingIDs)
        end
    end

    if self.db.profile.moveEngineering then
        if self.db.profile.showcoloredCategories then
            Result["|cff787878Engineering|r"] = AddToSet(EngineeringIDs)
        else
            Result[unescape("|cff787878Engineering|r")] = AddToSet(EngineeringIDs)
        end
    end

    if self.db.profile.moveInscription then
        if self.db.profile.showcoloredCategories then
            Result["|cff4dfaf8Inscription|r"] = AddToSet(InscriptionIDs)
        else
            Result[unescape("|cff4dfaf8Inscription|r")] = AddToSet(InscriptionIDs)
        end
    end

    if self.db.profile.moveGeneralCrafting then
        if self.db.profile.showcoloredCategories then
            Result["|cff51479cGeneral Crafting|r"] = AddToSet(GeneralCraftingIDs)
        else
            Result[unescape("|cff51479cGeneral Crafting|r")] = AddToSet(GeneralCraftingIDs)
        end
    end

    if self.db.profile.moveTreasureSacks then
        if self.db.profile.showcoloredCategories then
            Result["|cfffff000Treasure Sacks|r"] = AddToSet(TreasureSacksIDs)
        else
            Result[unescape("|cfffff000Treasure Sacks|r")] = AddToSet(TreasureSacksIDs)
        end
    end

    if self.db.profile.moveHerbs then
        if self.db.profile.showcoloredCategories then
            Result["|cff00ff36Herbs|r"] = AddToSet(HerbsIDs)
        else
            Result[unescape("|cff00ff36Herbs|r")] = AddToSet(HerbsIDs)
        end
    end

    if self.db.profile.moveMining then
        if self.db.profile.showcoloredCategories then
            Result["|cff898396Mining|r"] = AddToSet(MiningIDs)
        else
            Result[unescape("|cff898396Mining|r")] = AddToSet(MiningIDs)
        end
    end

    if self.db.profile.moveCloth then
        if self.db.profile.showcoloredCategories then
            Result["|cffff7e00Cloth|r"] = AddToSet(ClothIDs)
        else
            Result[unescape("|cffff7e00Cloth|r")] = AddToSet(ClothIDs)
        end
    end

    if self.db.profile.moveCooking then
        if self.db.profile.showcoloredCategories then
            Result["|cffff0072Cooking|r"] = AddToSet(CookingIDs)
        else
            Result[unescape("|cffff0072Cooking|r")] = AddToSet(CookingIDs)
        end
    end

    if self.db.profile.moveJewelcrafting then
        if self.db.profile.showcoloredCategories then
            Result["|cff514dfaJewelcrafting|r"] = AddToSet(JewelcraftingIDs)
        else
            Result[unescape("|cff514dfaJewelcrafting|r")] = AddToSet(JewelcraftingIDs)
        end
    end

    if self.db.profile.moveFortuneCards then
        if self.db.profile.showcoloredCategories then
            Result["|cff6cff00Fortune Cards|r"] = AddToSet(FortuneCardsIDs)
        else
            Result[unescape("|cff6cff00Fortune Cards|r")] = AddToSet(FortuneCardsIDs)
        end
    end

    if self.db.profile.moveDarkmoonCards then
        if self.db.profile.showcoloredCategories then
            Result["|cff48aa00Darkmoon Cards|r"] = AddToSet(DarkmoonCardsIDs)
        else
            Result[unescape("|cff48aa00Darkmoon Cards|r")] = AddToSet(DarkmoonCardsIDs)
        end
    end



    return Result
end

local setFilter = AdiBags:RegisterFilter("Dragonflight", 98, "ABEvent-1.0")
setFilter.uiName = "|cffA00000Dragonflight|r"
setFilter.uiDesc = "Items from the Dragonflight\n|cffFFD800Filter version: 1.1.4|r"

function setFilter:OnInitialize()
    self.db = AdiBags.db:RegisterNamespace("Dragonflight", {
        profile = {
            
            movePreEventGear = true,
            moveAlchemy = false,
            movePreEventCurrency = true,
            moveLeather = false,
            moveEnchanting = false,
            moveEngineering = false,
            moveInscription = false,
            moveGeneralCrafting = false,
            moveTreasureSacks = true,
            moveHerbs = false,
            moveMining = false,
            moveCloth = false,
            moveCooking = false,
            moveJewelcrafting = false,
            moveFortuneCards = true,
            moveDarkmoonCards = true,
            showcoloredCategories = true,
        }
    })
end

function setFilter:Update()
    MatchIDs = nil
    self:SendMessage("AdiBags_FiltersChanged")
end

function setFilter:OnEnable()
    AdiBags:UpdateFilters()
end

function setFilter:OnDisable()
    AdiBags:UpdateFilters()
end

function setFilter:Filter(slotData)
    MatchIDs = MatchIDs or MatchIDs_Init(self)
    for i, name in pairs(MatchIDs) do
        -- Override Method
        if MatchIDs[i]['override'] then
            slotData['loc'] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
            if slotData['loc']  and slotData['loc']:IsValid() then
                if MatchIDs[i]['override_method'](slotData.loc) then
                    return i
                end
            end

        -- Bonus Condition (triggers when bonus condition is not fulfilled)
        elseif MatchIDs[i]['bonus_condition'] then
            if name[slotData.itemId] then
                slotData['loc'] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
                if slotData['loc'] and slotData['loc']:IsValid() then
                    if not MatchIDs[i]['bonus_condition_method'](slotData.loc) then -- THERE IS A NOT HERE!
                        return i
                    end
                end
            end

        -- Standard ID Matching
        elseif name[slotData.itemId] then
            return i
        end
    end
end

function setFilter:GetOptions()
    return {
        movePreEventGear = {
            name = "PreEvent Gear",
            desc = "Gear dropped or bought in the Dragonflight Pre-Patch Event",
            type = "toggle",
            order = 10
        },

        moveAlchemy = {
            name = "Alchemy",
            desc = "Crafting Reagents of the 'Alchemy' category (flasks only, you may also want to enable Herbs)",
            type = "toggle",
            order = 20
        },

        movePreEventCurrency = {
            name = "PreEvent Currency",
            desc = "Currency-like items dropped in the Dragonflight Pre-Patch Event",
            type = "toggle",
            order = 30
        },

        moveLeather = {
            name = "Leather",
            desc = "Crafting Reagents of the 'Leather' category",
            type = "toggle",
            order = 40
        },

        moveEnchanting = {
            name = "Enchanting",
            desc = "Crafting Reagents of the 'Enchanting' category",
            type = "toggle",
            order = 50
        },

        moveEngineering = {
            name = "Engineering",
            desc = "Crafting Reagents of the 'Engineering' category",
            type = "toggle",
            order = 60
        },

        moveInscription = {
            name = "Inscription",
            desc = "Crafting Reagents of the 'Inscription' category",
            type = "toggle",
            order = 70
        },

        moveGeneralCrafting = {
            name = "General Crafting",
            desc = "General Crafting Reagents, used by multiple professions",
            type = "toggle",
            order = 80
        },

        moveTreasureSacks = {
            name = "Treasure Sacks",
            desc = "Treasure Sacks",
            type = "toggle",
            order = 90
        },

        moveHerbs = {
            name = "Herbs",
            desc = "Crafting Reagents of the 'Herbs' category",
            type = "toggle",
            order = 100
        },

        moveMining = {
            name = "Mining",
            desc = "Crafting Reagents of the 'Mining' category",
            type = "toggle",
            order = 110
        },

        moveCloth = {
            name = "Cloth",
            desc = "Crafting Reagents of the 'Cloth' category",
            type = "toggle",
            order = 120
        },

        moveCooking = {
            name = "Cooking",
            desc = "Crafting Reagents of the 'Cooking' category",
            type = "toggle",
            order = 130
        },

        moveJewelcrafting = {
            name = "Jewelcrafting",
            desc = "Crafting Reagents of the 'Jewelcrafting' category",
            type = "toggle",
            order = 140
        },

        moveFortuneCards = {
            name = "Fortune Cards",
            desc = "Fortune Cards",
            type = "toggle",
            order = 150
        },

        moveDarkmoonCards = {
            name = "Darkmoon Cards",
            desc = "Darkmoon Cards",
            type = "toggle",
            order = 160
        },

        showcoloredCategories = {
            name = "|cffff98abC|cffffa094o|cffffa77el|cffffaf67o|cfffebf71r|cfffecf7be|cfffddf85d|cffe0d988 |cffc3d38bC|cffa6cd8ea|cff9bccaet|cff8fcbcde|cff95bad2g|cff9aa9d7o|cffa098dcr|cffae98dci|cffbd98dce|cffcb98dcs|r",
            desc = "Should Categories be colored?",
            type = "toggle",
            order = 170
        },


    },
    AdiBags:GetOptionHandler(self, false, function ()
        return self:Update()
    end)
end
